list

Function list 

pub fn list() -> Result<()>
Lists files in the local archive cache.

Errors

Returns an error if the archive cache root cannot be determined or if reading the directory fails.

Panics

This function does not explicitly panic.