pub fn run( package_name: &str, location: Option<String>, yes: bool, ) -> Result<()>
Runs the clone command to clone a package’s git repository.
clone
Returns an error if the package cannot be resolved, if its metadata cannot be parsed, if it has no git repository defined, or if the git clone command fails.
git clone
This function does not explicitly panic.