pub fn run(run_cmd: Option<String>, repo: Option<String>) -> Result<()>Expand description
Runs the dev command to enter a development shell for a project.
Errors
Returns an error if the development shell cannot be entered or dependencies cannot be resolved.