Module downgrade

Module downgrade 

The downgrade command. Implementation of the downgrade command for switching to older package versions.

Functions

run
Runs the downgrade command to switch to an older version of a package.