run

Function run 

pub fn run(
    package_name: &str,
    yes: bool,
    plugin_manager: Option<&PluginManager>,
) -> Result<()>
Runs the downgrade command to switch to an older version of a package.

Errors

Returns an error if the package cannot be resolved, no other versions are found, or the installation of the selected version fails.