Module download

Module download 

The download command. Implementation of the download command for downloading package archives.

Enums

DownloadType
Type of download to perform.

Functions

run
Runs the download command to download a package archive or source bundle.