run

Function run 

pub fn run(env_alias: Option<&str>, export_shell: Option<Shell>) -> Result<()>
Runs the ‘env’ command.

Sets up the environment for a project or exports shell configuration for environment variables.

Errors

Returns an error if the project configuration cannot be loaded or if environment setup/export fails.