Module exec

Module exec 

The exec command. Implementation of the zoi exec command.

This command allows running a binary from a package without explicitly installing it into the global or user scope. It handles temporary installation and cleanup.

Functions

run
Runs the ‘exec’ command.