run

Function run 

pub fn run(package_name: &str) -> Result<()>
Runs the ‘files’ command.

Lists all files installed as part of the specified package.

Errors

Returns an error if the package is not installed or if there is an issue resolving the package metadata or files.