Module helper

Module helper 

The helper command. Helper commands for the Zoi CLI.

These commands are primarily used for internal operations, debugging, or utility tasks like hashing files and validating configuration.

Structs

ElevateInstallNodeCommand
Arguments for the escalated install-node command.
ElevateUninstallCommand
Arguments for the escalated uninstall command.
GetHashCommand
Arguments for the get-hash command.
HelperCommand
The root helper command.
ValidateCommand
Arguments for the validate command.

Enums

HashAlgorithm
Supported hash algorithms for the get-hash command.
HelperCommands
Available helper subcommands.

Functions

run
Run the helper command.