run

Function run 

pub fn run(branch: &str, status: &str, number: &str, commit: &str) -> Result<()>
Runs the ‘info’ command.

Displays detailed information about the system, platform, package managers, and Zoi configuration.

Errors

Returns an error if the platform information or configuration cannot be retrieved.