Module installed_select

Module installed_select 

The installed_select command. Utilities for selecting from multiple installed versions of a package.

Functions

choose_installed_manifest
Prompts the user to select an installed manifest from a list of candidates.