The list command.
Command for listing installed or available packages.
This module provides functionality to list packages based on various filters like registry, repository, package type, and outdated status.
Functions
- run
- Runs the list command with the provided filters and options.