run

Function run 

pub fn run(path: &Path) -> Result<()>
Runs the owner command.

Errors

Returns an error if the path does not exist, or if there is an error querying the package database or ownership information.