Module package

Module package 

The package command. Package development and maintenance commands.

This module provides tools for package maintainers to build, test, bundle, and validate Zoi packages.

Modules

build
Build command module. Logic for the package build command.
bundle
Bundle command module. Implementation of the package bundle command.
doctor
Doctor command module. Implementation of the package doctor command, which validates package specification files.
init_lsp
Init-LSP command module. Initialization of LSP support for package development.
inspect
Inspect command module. Inspection of package files.
install
Install command module. Installation of package archive files.
test
Test command module. Running tests for packages.

Structs

PackageCommand
Arguments for the package command.

Functions

run
Runs the package command.