Build command module.
Logic for the package build command.
This module provides the functionality to build Zoi packages from their definition files, handling dependencies, platforms, and isolation.
Structs
- Build
Command - Arguments for the
package buildcommand.
Functions
- install_
dependencies_ for_ build - Install dependencies required for building the package.
- run
- Run the package build command.