run

Function run 

pub fn run(args: BundleCommand) -> Result<()>
Runs the package bundle command.

Errors

Returns an error if the package cannot be bundled, if there are missing dependencies, or if there is an error writing the bundle file.