run

Function run 

pub fn run(term: &str) -> Result<()>
Searches for packages that provide a specific file or command.

This queries the configured registries to find which packages contain the given term in their file lists.

Errors

This function will return an error if:

  • It fails to read the Zoi configuration.
  • It fails to connect to the package database or execute the query.

Errors

Returns an error if the provides search fails.