The search command.
Command for searching packages or files in registries.
This module provides functionality to search for packages by name, description, or tags, as well as searching for specific files within packages. It supports both a standard table output and an interactive TUI.
Functions
- run
- Runs the search command with the provided terms and options.