The shell command.
Functions
- enter_
ephemeral_ shell - Enters an ephemeral shell with the given packages installed.
- print_
hook - Prints the shell hook script for a given shell.
- run
- Runs the shell setup command.
The shell command.