print_hook

Function print_hook 

pub fn print_hook(shell: Shell) -> Result<()>
Prints the shell hook script for a given shell.

Errors

Returns an error if the shell hook is not supported for the given shell.