Module system

Module system 

The system command. Logic for the system command.

This module provides commands for managing ZoiOS systems, including declarative configuration, system generations, secrets management, and distribution building.

Structs

SystemCommand
The root system management command.

Enums

DistroSubcommands
Commands for building and managing ZoiOS distributions.
SecretSubcommands
Commands for managing secrets like password hashes and encrypted strings.
SystemSubcommands
Available system subcommands.

Functions

run
Run the system management command.