pub enum SecretSubcommands {
Hash {
password: String,
},
Encrypt {
value: String,
},
Decrypt {
secret: String,
},
}Variants
Hash
Generate a one-way hash of a password for use in system.lua
Encrypt
Encrypt a sensitive string (like an API key) so only Zoi can decrypt it
Decrypt
Decrypt a ZOISEC string (only works on the same machine where it was encrypted)