pub fn run(cmd: TelemetryCommand) -> Result<()>Expand description
Run the telemetry command.
Errors
Returns an error if the configuration cannot be read or written.
pub fn run(cmd: TelemetryCommand) -> Result<()>Run the telemetry command.
Returns an error if the configuration cannot be read or written.