run

Function run 

pub fn run(package_names: &[String]) -> Result<()>
Runs the tree command to display the dependency tree of one or more packages.

Errors

Returns an error if the dependency tree cannot be resolved.