run

Function run 

pub fn run(
    package_names: &[String],
    scope: Option<InstallScope>,
    local: bool,
    global: bool,
    save: bool,
    yes: bool,
    recursive: bool,
    plugin_manager: Option<&PluginManager>,
    explain: bool,
    plan_json: bool,
    dry_run: bool,
) -> Result<()>
Runs the uninstall command to remove one or more packages.

Errors

Returns an error if:

  • The –save flag is used with a non-project scope.
  • Package resolution fails for any of the provided names.
  • Uninstallation fails for any resolved package.
  • A transaction cannot be started, recorded, or committed.