pub enum InstallOrigin {
RegistryPrebuilt,
RegistrySource,
LocalArchive,
LocalPackage,
RemoteUrl,
Unknown,
}Expand description
Classifies the source and method used to install a package.
This is used for reporting and telemetry to understand where packages are coming from in the ecosystem.
Variants
Implementations