pub fn classify_source_origin(source: &str, action_name: &str) -> InstallOriginExpand description
Classifies the origin of a package based on its source string and the action being performed.
pub fn classify_source_origin(source: &str, action_name: &str) -> InstallOriginClassifies the origin of a package based on its source string and the action being performed.