run

Function run 

pub fn run(package_name: &str) -> Result<()>
Run the why command.

Errors

Returns an error if the package is not installed or if there is an error reading the package metadata or dependents.