pub fn get_package_dir(
scope: Scope,
registry_handle: &str,
repo_path: &str,
package_name: &str,
) -> Result<PathBuf, Error>Expand description
Returns the directory for a specific package in the store.
Errors
Returns an error if the package directory path cannot be constructed.