get_package_source_path

Function get_package_source_path 

pub fn get_package_source_path(
    manifest: &InstallManifest,
) -> Result<PathBuf, Error>
Returns the path where the package source file should be stored.

Errors

Returns an error if the source path cannot be constructed.