get_package_version_dir

Function get_package_version_dir 

pub fn get_package_version_dir(
    scope: Scope,
    registry_handle: &str,
    repo_path: &str,
    package_name: &str,
    version: &str,
) -> Result<PathBuf, Error>
Returns the directory for a specific version of a package in the store.

Errors

Returns an error if the package version directory path cannot be constructed.