get_store_base_dir

Function get_store_base_dir 

pub fn get_store_base_dir(scope: Scope) -> Result<PathBuf, Error>
Returns the base directory of the package store for a given scope.

Errors

Returns an error if the store base directory cannot be determined.