release_lock

Function release_lock 

pub fn release_lock() -> Result<(), Error>
Returns an error because only dropping the owning LockGuard can release the advisory lock. The lock file itself is intentionally never removed because unlinking it can let a waiting process and a newly-created inode be locked concurrently.

Errors

Returns an error if the lock path cannot be determined.