get_pgp_dir

Function get_pgp_dir 

pub fn get_pgp_dir() -> Result<PathBuf, Error>
Returns the path to the local PGP keyring directory.

This usually resides at ~/.zoi/pgps/. The directory is created if it does not exist.

Errors

Returns an error if the home directory cannot be found or the PGP directory cannot be created.