show_key

Function show_key 

pub fn show_key(name: &str) -> Result<(), Error>
Prints the ASCII-armored content of a PGP key from the local keyring.

Errors

Returns an error if the key with the given name is not found or cannot be read.