Module autoremove

Module autoremove 

Logic for automatically removing unused dependencies. Automatic removal of unused dependencies.

Functions

run
Runs the autoremove operation, identifying and removing packages that were installed as dependencies but are no longer required by any other package.