System doctor utilities.
Structs
- Tool
Check Result - Result of checking for external tool dependencies.
Functions
- check_
broken_ symlinks - Checks for broken symlinks in all binary shim directories.
- check_
duplicate_ packages - Finds packages that are defined in multiple registries.
- check_
external_ tools - Checks if essential and recommended external tools are available in PATH.
- check_
ghost_ dependents - Finds “ghost” dependent links (links from packages that are no longer installed).
- check_
lockfile_ mismatch - Checks for “Lockfile Mismatch” (zoi.lock targets a different platform).
- check_
orphaned_ packages - Finds orphaned packages (dependencies no longer required by any package).
- check_
outdated_ repos - Checks if any repositories are significantly out of date.
- check_
path_ configuration - Checks if Zoi’s binary directory is in the system PATH.
- check_
pgp_ configuration - Checks if PGP keys required by security policy are present in the keyring.
- check_
registry_ drift - Checks for “Registry Drift” (local
.pkg.luadiffers from the database). - prune_
ghost_ dependents - Removes stale dependent links identified by
check_ghost_dependents. - validate_
lockfile_ integrity - Validates that all packages recorded in the lockfile are actually installed.