pub fn add(
ext_name: &str,
yes: bool,
plugin_manager: Option<&PluginManager>,
) -> Result<(), Error>Expand description
Installs an extension, applying its declared changes to the system and registry configuration.
Errors
Returns an error if the extension package cannot be resolved, if it’s not an extension package, or if applying any of the changes fails.