get_hash

Function get_hash 

pub fn get_hash(source: &str, hash_type: HashType) -> Result<String>
Calculates the hash of a file or remote URL.

Errors

Returns an error if the file cannot be opened or read, or if the remote URL cannot be downloaded.