pub fn run(file: &Path) -> Result<()>Expand description
Validates a Zoi specification file (e.g. registries.json, repo.yaml).
Errors
Returns an error if the file does not exist, cannot be read, or if the file content does not match any known Zoi specification.