get_installed_packages

Function get_installed_packages 

pub fn get_installed_packages() -> Result<Vec<InstallManifest>, Error>
Returns a list of all installed packages across all scopes.

Errors

Returns an error if the store cannot be accessed or manifests cannot be read.