pub fn get_package_source_path( manifest: &InstallManifest, ) -> Result<PathBuf, Error>
Returns the path where the package source file should be stored.
Returns an error if the source path cannot be constructed.