is_package_installed

Function is_package_installed 

pub fn is_package_installed(
    package_name: &str,
    sub_package_name: Option<&str>,
    scope: Scope,
) -> Result<Option<InstallManifest>, Error>
Checks if a package is installed in a given scope and returns its manifest if found.

Errors

Returns an error if the store cannot be accessed or manifests cannot be read.