write_manifest

Function write_manifest 

pub fn write_manifest(manifest: &InstallManifest) -> Result<(), Error>
Writes an installation manifest to the store and updates the ‘latest’ symlink.

Errors

Returns an error if the manifest cannot be serialized or written.