Module lock

Module lock 

Lock file management.

Structs

LockGuard
A guard that releases the system-wide lock when dropped.

Functions

acquire_lock
Acquires a system-wide lock to prevent concurrent modifications to the Zoi store.
release_lock
Returns an error because only dropping the owning LockGuard can release the advisory lock. The lock file itself is intentionally never removed because unlinking it can let a waiting process and a newly-created inode be locked concurrently.