Minimal package resolution utilities.
Structs
- Mini
Package Index - A simplified version of package metadata used in Zoi Mini’s remote index.
- Mini
Registry Index - A mapping of package names to their metadata in the Mini index.
- Mini
Vulnerability - A simplified vulnerability representation used in package indices.
Functions
- check_
vulnerabilities - Scans the package metadata for known security advisories.
- fetch_
registry_ config - Fetches the repository configuration from the official Zoidberg registry.
- fetch_
registry_ index - Fetches the optimized JSON index from the official Zoidberg registry.
- get_
package_ lua_ url - Returns the URL to download a package’s
.pkg.luafile from the official registry.