fetch_registry_config

Function fetch_registry_config 

pub fn fetch_registry_config() -> Result<RepoConfig, Error>
Fetches the repository configuration from the official Zoidberg registry.

Errors

Returns an error if the configuration cannot be fetched or parsed.