pub struct MiniPackageIndex {
pub repo: String,
pub repo_type: String,
pub version: String,
pub revision: String,
pub description: String,
pub sub_packages: Option<Vec<String>>,
pub vuln: Option<Vec<MiniVulnerability>>,
}Expand description
A simplified version of package metadata used in Zoi Mini’s remote index.
This index allows Zoi Mini to perform fast lookups and vulnerability checks
without downloading individual .pkg.lua files or cloning entire registries.
Fields
repo: Stringrepo_type: Stringversion: Stringrevision: Stringdescription: Stringsub_packages: Option<Vec<String>>vuln: Option<Vec<MiniVulnerability>>Trait Implementations
Sourceimpl Clone for MiniPackageIndex
impl Clone for MiniPackageIndex
Sourcefn clone(&self) -> MiniPackageIndex
fn clone(&self) -> MiniPackageIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MiniPackageIndex
impl Debug for MiniPackageIndex
Sourceimpl<'de> Deserialize<'de> for MiniPackageIndex
impl<'de> Deserialize<'de> for MiniPackageIndex
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MiniPackageIndex, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MiniPackageIndex, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for MiniPackageIndex
impl Serialize for MiniPackageIndex
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more