pub fn run(
package_file: &Path,
build_type: Option<&str>,
platforms: &[String],
sign_key: Option<String>,
output_dir: Option<&Path>,
version_override: Option<&str>,
sub_packages: Option<Vec<String>>,
quiet: bool,
method: &str,
image: Option<&str>,
fakeroot: bool,
install_deps: bool,
test: bool,
) -> Result<(), Error>Expand description
Executes the build process for one or more platforms.
Errors
Returns an error if:
- A .zsa bundle cannot be extracted.
- The required image is not specified for Docker builds.
- Building for ‘all’ platforms is requested.
- One or more platform builds fail.