Module bwrap

Module bwrap 

Linux isolation using Bubblewrap. Linux isolation using Bubblewrap.

This module provides a way to run Zoi package builds inside a Bubblewrap (bwrap) sandbox on Linux. This ensures that the build process is isolated from the host system and has restricted access to the filesystem and network.

Functions

run
Runs the package build process inside a Bubblewrap sandbox.