Module relocate

Module relocate 

ELF binary relocation for portability. ELF binary relocation for portability.

This module provides utilities for rewriting the RPATH/RUNPATH of ELF binaries to use relative paths (using $ORIGIN). This makes packages relocatable, allowing them to find their shared libraries regardless of their install location.

Functions

relocate_elfs
Automatically identifies ELF binaries and shared libraries in the staging area and rewrites their RUNPATH/RPATH to use $ORIGIN relative paths.