run

Function run 

pub fn run(args: &BuildCommand) -> Result<()>
Runs tests for a Zoi package defined in a .pkg.lua file.

Errors

Returns an error if the package file cannot be parsed, if the build environment cannot be set up, or if the package tests fail.