search_keys

Function search_keys 

pub fn search_keys(term: &str) -> Result<(), Error>
Searches for PGP keys in the local keyring by name, fingerprint, or UserID (name/email).

Errors

Returns an error if the local keyring cannot be read.