Package pinning management.
Structs
- Pinned
Package - Represents a package pinned to a specific version from a specific source.
Functions
- get_
pinned_ packages - Loads the list of pinned packages from
pinned.json. - get_
pinned_ version - Retrieves the pinned version for a given source, if it exists.
- is_
pinned - Checks if a source has a pinned version.
- write_
pinned_ packages - Saves the list of pinned packages to
pinned.json.