Transaction recording and playback.
Functions
- get_
recorded_ packages - Returns all recorded packages across all scopes.
- record_
package - Records a package installation or update in the lockfile.
- remove_
package_ from_ record - Removes a package from the lockfile record.
- update_
package_ reason - Updates the installation reason for a package in the lockfile.