Module registry

Module registry 

Package registry utilities.

Functions

add_advisory
Adds a new security advisory to the registry.
add_package
Adds a new package definition to the registry.
check
Checks the integrity of all package definitions in the registry.
generate_metadata
Scans the entire registry to generate optimized JSON index files.
init
Initializes a new Zoi registry at the given path.