init

Function init 

pub fn init(path: &Path) -> Result<(), Error>
Initializes a new Zoi registry at the given path.

This creates the necessary directory structure, repo.yaml, packages.json, and advisories.json, and sets up LSP support.

Errors

Returns an error if:

  • The registry directory or its subdirectories cannot be created.
  • LSP workspace setup fails.
  • Any of the initial configuration files cannot be written.