Package resolution utilities.
Structs
- Package
Request - Represents a request for a package, parsed from a source string.
- Resolved
Source - Represents a source that has been resolved to a local path.
Functions
- get_
db_ root - Returns the root directory of the package database.
- get_
default_ version - Returns the default version for a package.
- parse_
source_ string - Parses a source string into a
PackageRequest. - resolve_
channel - Resolves a channel name to a concrete version.
- resolve_
package_ and_ version - Resolves a package and its version from a source string.
- resolve_
requested_ version_ spec - Resolves the requested version specification from a source string.
- resolve_
source - Resolves a source identifier into a concrete local path to a
.pkg.luafile. - resolve_
version_ from_ url - Resolves a version from a JSON URL for a given channel.