pub fn resolve_requested_version_spec(
source_str: &str,
scope: Option<Scope>,
quiet: bool,
yes: bool,
) -> Result<Option<String>, Error>Expand description
Resolves the requested version specification from a source string.
Errors
Returns an error if the source string format is invalid or if resolution fails.