Module shim

Module shim 

Shim management utilities.

Functions

create_shim
Creates a shim for the current Zoi executable at the specified path.
resolve_to_installed_bin
Resolves a binary name to its installed path in the Zoi store.
run_shim
Runs a binary through the Zoi shim mechanism.