create_shim

Function create_shim 

pub fn create_shim(link_path: &Path) -> Result<(), Error>
Creates a shim for the current Zoi executable at the specified path.

Errors

Returns an error if the current executable path cannot be determined or if creating the symbolic link fails.