InstallManifest

Struct InstallManifest 

pub struct InstallManifest {
Show 28 fields pub name: String, pub version: String, pub epoch: u32, pub revision: String, pub sub_package: Option<String>, pub repo: String, pub repo_type: String, pub registry_handle: String, pub package_type: PackageType, pub description: String, pub reason: InstallReason, pub scope: Scope, pub bins: Option<Vec<String>>, pub conflicts: Option<Vec<String>>, pub replaces: Option<Vec<String>>, pub provides: Option<Vec<String>>, pub backup: Option<Vec<String>>, pub installed_dependencies: Vec<String>, pub dependencies_v2: Option<DependenciesV2>, pub chosen_options: Vec<String>, pub chosen_optionals: Vec<String>, pub install_method: Option<String>, pub platform: String, pub service: Option<Service>, pub installed_files: Vec<String>, pub installed_size: Option<u64>, pub sandbox: Option<SandboxConfig>, pub completions: Option<Vec<ShellCompletion>>,
}
The record of an actual package installation on disk.

Unlike the Package blueprint, the InstallManifest is the “Source of Truth” for what is currently installed. It is stored in manifest.yaml inside the package’s version directory in the Zoi store.

Fields

name: String

Name of the installed package.

version: String

Exact version installed.

epoch: u32

Forced version precedence.

revision: String

Revision of the package definition used for this install.

sub_package: Option<String>

For split packages, the name of the installed sub-package.

repo: String

Repository tier the package came from.

repo_type: String

Trust level of the repository (official, community, etc.).

registry_handle: String

Registry handle the package was installed from.

package_type: PackageType

Category of the installed package.

description: String

Short summary.

reason: InstallReason

Whether the user installed this directly or if it’s a dependency.

scope: Scope

The scope where this package was installed.

bins: Option<Vec<String>>

List of linked binary names.

conflicts: Option<Vec<String>>replaces: Option<Vec<String>>provides: Option<Vec<String>>backup: Option<Vec<String>>installed_dependencies: Vec<String>dependencies_v2: Option<DependenciesV2>chosen_options: Vec<String>chosen_optionals: Vec<String>install_method: Option<String>platform: Stringservice: Option<Service>installed_files: Vec<String>installed_size: Option<u64>sandbox: Option<SandboxConfig>completions: Option<Vec<ShellCompletion>>

Implementations