pub fn confirm_untrusted_source(
source_type: &SourceType,
yes: bool,
) -> Result<(), Error>Expand description
Prompts the user to confirm installation from an untrusted (non-official) source.
Errors
Returns an error if the user aborts the operation.