pub fn copy_dir_all(src: &Path, dst: &Path) -> Result<(), Error>
Recursively copies all files and subdirectories from source to destination.
Returns an error if the directory creation or file copy operation fails.