run_shell_command

Function run_shell_command 

pub fn run_shell_command(command_str: &str) -> Result<(), Error>
Executes a shell command and returns an error if it fails.

Errors

Returns an error if the command fails to execute or returns a non-zero exit status.