pub fn set_path_owner(
path: &Path,
owner: &str,
group: &str,
) -> Result<(), Error>Expand description
Sets the owner and group for a file or directory (Unix only).
Errors
Returns an error if the owner or group lookup fails, or if the chown operation fails.