remove_package_from_record

Function remove_package_from_record 

pub fn remove_package_from_record(
    manifest: &InstallManifest,
) -> Result<(), Error>
Removes a package from the lockfile record.

Errors

Returns an error if the lockfile cannot be read or written, or if the lockfile mutex is poisoned.