apply_sysroot

Function apply_sysroot 

pub fn apply_sysroot(path: impl Into<PathBuf>) -> PathBuf
Prepends the sysroot to the given path if a sysroot is set. If the path is absolute, it is made relative to the current root before joining.