pub struct Config {Show 20 fields
pub repos: Vec<String>,
pub package_managers: Option<Vec<String>>,
pub native_package_manager: Option<String>,
pub telemetry_enabled: bool,
pub audit_log_enabled: bool,
pub registry: Option<String>,
pub default_registry: Option<Registry>,
pub added_registries: Vec<Registry>,
pub git_repos: Vec<String>,
pub rollback_enabled: bool,
pub policy: Policy,
pub remote_policy: Option<RemotePolicyConfig>,
pub jobs: Option<usize>,
pub protect_db: bool,
pub max_resolution_depth: Option<u8>,
pub offline_mode: bool,
pub pkg_dirs: Vec<String>,
pub cache_mirrors: Vec<String>,
pub versions: HashMap<String, String>,
pub system_generations_limit: u32,
}Expand description
The global Zoi configuration.
Fields
repos: Vec<String>The list of repository tiers enabled globally.
package_managers: Option<Vec<String>>The list of supported package managers.
native_package_manager: Option<String>The primary native package manager for the system.
telemetry_enabled: boolWhether telemetry collection is enabled.
audit_log_enabled: boolWhether audit logging is enabled.
registry: Option<String>The handle of the primary registry.
default_registry: Option<Registry>The default registry configuration.
added_registries: Vec<Registry>The list of additional registries.
git_repos: Vec<String>The list of third-party Git repositories to include in resolution.
rollback_enabled: boolWhether rollback functionality is enabled.
policy: PolicyThe local policy configuration.
remote_policy: Option<RemotePolicyConfig>The remote policy configuration.
jobs: Option<usize>The maximum number of concurrent jobs to use for builds and downloads.
protect_db: boolWhether to protect the Zoi database from unauthorized modifications.
max_resolution_depth: Option<u8>The maximum depth for recursive dependency resolution.
offline_mode: boolWhether Zoi should operate in offline mode.
pkg_dirs: Vec<String>The list of directories where packages are stored.
cache_mirrors: Vec<String>The list of mirror URLs for the package cache.
versions: HashMap<String, String>A map of package names to pinned versions.
system_generations_limit: u32The maximum number of system generations to keep for rollbacks.