setup_path

Function setup_path 

pub fn setup_path(scope: Scope) -> Result<()>
Sets up the PATH environment variable for the given scope.

Errors

Returns an error if:

  • The home directory cannot be found for the user scope.
  • The directory for binaries cannot be created.
  • The shell configuration file cannot be read, created, or written to.
  • On Windows, the registry key for environment variables cannot be opened or modified.
  • Administrator privileges are missing for system scope on Windows.