Function run
Source pub fn run(
all: bool,
registry_filter: Option<String>,
repo_filter: Option<&str>,
) -> Result<()>
Executes the audit command.
Errors
Returns an error if the configuration cannot be read, if the database cannot
be accessed, or if local package information cannot be retrieved.
Panics
This function does not explicitly panic, but underlying library calls might.