run

Function run 

pub fn run(shell: Shell, index: usize, words: &[String]) -> Result<()>
Runs the complete command to provide shell autocompletion suggestions.

Errors

This function is currently infallible but returns Result for consistency.