run

Function run 

pub fn run(run_cmd: Option<String>, repo: Option<String>) -> Result<()>
Runs the dev command to enter a development shell for a project.

Errors

Returns an error if the development shell cannot be entered or dependencies cannot be resolved.