pub fn run(args: HomeCommand) -> Result<()>Expand description
Run the home management command.
Errors
Returns an error if not on a ZoiOS system, if the home configuration
cannot be loaded or applied, or if user packages fail to install.
pub fn run(args: HomeCommand) -> Result<()>Run the home management command.
Returns an error if not on a ZoiOS system, if the home configuration
cannot be loaded or applied, or if user packages fail to install.