pub fn run(branch: &str, status: &str, number: &str, commit: &str) -> Result<()>Expand description
Runs the ‘info’ command.
Displays detailed information about the system, platform, package managers, and Zoi configuration.
Errors
Returns an error if the platform information or configuration cannot be retrieved.