The installed_select command.
Utilities for selecting from multiple installed versions of a package.
Functions
- choose_
installed_ manifest - Prompts the user to select an installed manifest from a list of candidates.
The installed_select command.
Utilities for selecting from multiple installed versions of a package.