pub fn run(
all: bool,
outdated: bool,
registry_filter: Option<&str>,
repo_filter: Option<&str>,
type_filter: Option<&str>,
foreign: bool,
names_only: bool,
completion: bool,
) -> Result<()>Expand description
Runs the list command with the provided filters and options.
Errors
Returns an error if:
- The package type filter is invalid.
- The
--foreignflag is used with--all. - There is an error reading the configuration or interacting with the database.
- There is an error fetching installed or available packages.
Panics
Panics if the type_filter is missing despite being set, which should not
happen.