Module build

Module build 

Build command module. Logic for the package build command.

This module provides the functionality to build Zoi packages from their definition files, handling dependencies, platforms, and isolation.

Structs

BuildCommand
Arguments for the package build command.

Functions

install_dependencies_for_build
Install dependencies required for building the package.
run
Run the package build command.