pub fn run(args: BuildCommand) -> Result<()>Expand description
Run the package build command.
Errors
Returns an error if the build fails, dependencies cannot be installed, or the pure environment cannot be initialized.
pub fn run(args: BuildCommand) -> Result<()>Run the package build command.
Returns an error if the build fails, dependencies cannot be installed, or the pure environment cannot be initialized.