run

Function run 

pub fn run(args: &BuildCommand) -> Result<()>
Runs tests for a package.

This command builds the package and runs its defined tests. If install_deps is set, it will also install necessary build dependencies.

Errors

Returns an error if the tests fail or dependencies cannot be installed.