pub fn run(source: &str, version: &str) -> Result<()>Expand description
Pins a package to a specific version.
This prevents the package from being updated to a newer version during general upgrades.
Errors
Returns an error if the package cannot be resolved or if the pinned packages file cannot be read or written.