Module shell

Module shell 

The shell command.

Functions

enter_ephemeral_shell
Enters an ephemeral shell with the given packages installed.
print_hook
Prints the shell hook script for a given shell.
run
Runs the shell setup command.