Module sync

Module sync 

The sync command. Logic for the sync command.

This module provides commands for syncing package databases from registries, and managing the list of configured registries.

Functions

add_registry
Add a new registry URL to the list of tracked registries.
list_registries
List all configured and tracked registries.
remove_registry
Remove a registry by its handle or URL.
run
Run the sync command to update package databases.
run_local
Run a project-local sync command.
set_registry
Set the default registry URL or use a pre-defined keyword.