The system command.
Logic for the system command.
This module provides commands for managing ZoiOS systems, including declarative configuration, system generations, secrets management, and distribution building.
Structs
- System
Command - The root system management command.
Enums
- Distro
Subcommands - Commands for building and managing
ZoiOSdistributions. - Secret
Subcommands - Commands for managing secrets like password hashes and encrypted strings.
- System
Subcommands - Available system subcommands.
Functions
- run
- Run the system management command.