Functions
- add_
added_ registry - add_
cache_ mirror - add_
repo - clone_
git_ repo - get_
all_ repos - get_
builtin_ authorities - Returns the built-in PGP authorities for the default registry.
- get_
default_ registry - Returns the default registry URL for Zoi.
- interactive_
add_ repo - list_
git_ repos - read_
config - Loads and merges configuration from system, user, and project-local paths.
- read_
repo_ config - read_
user_ config - remove_
added_ registry - remove_
cache_ mirror - remove_
git_ repo - remove_
repo - set_
default_ registry - set_
user_ default_ registry - sync_
remote_ policy - Synchronizes the remote security policy if configured in system
config.yaml. - update_
global_ versions - verify_
remote_ file - write_
user_ config - Writes the user-specific configuration to disk.