pub fn remove_added_registry(handle_or_url: &str) -> Result<(), Error>
Removes an added registry by its handle or URL.
Returns an error if the registry is not found or the configuration cannot be updated.