run

Function run 

pub fn run(
    source: &str,
    app_name: Option<String>,
    yes: bool,
    plugin_manager: Option<&PluginManager>,
) -> Result<(), Error>
Runs the app creation process.

This involves resolving the package, building it as an app template, and then installing it to the target directory.

Errors

Returns an error if:

  • The package cannot be resolved.
  • The package type is not ‘app’.
  • The build process fails.
  • The installation to the target directory fails.