Module doctor

Module doctor 

System doctor utilities.

Structs

ToolCheckResult
Result of checking for external tool dependencies.

Functions

check_broken_symlinks
Checks for broken symlinks in all binary shim directories.
check_duplicate_packages
Finds packages that are defined in multiple registries.
check_external_tools
Checks if essential and recommended external tools are available in PATH.
check_ghost_dependents
Finds “ghost” dependent links (links from packages that are no longer installed).
check_lockfile_mismatch
Checks for “Lockfile Mismatch” (zoi.lock targets a different platform).
check_orphaned_packages
Finds orphaned packages (dependencies no longer required by any package).
check_outdated_repos
Checks if any repositories are significantly out of date.
check_path_configuration
Checks if Zoi’s binary directory is in the system PATH.
check_pgp_configuration
Checks if PGP keys required by security policy are present in the keyring.
check_registry_drift
Checks for “Registry Drift” (local .pkg.lua differs from the database).
prune_ghost_dependents
Removes stale dependent links identified by check_ghost_dependents.
validate_lockfile_integrity
Validates that all packages recorded in the lockfile are actually installed.