pub fn remove(
ext_name: &str,
yes: bool,
plugin_manager: Option<&PluginManager>,
) -> Result<(), Error>Expand description
Uninstalls an extension and reverts all changes it made to the system and configuration.
Errors
Returns an error if the extension is not installed, if it’s not an extension package, or if reverting any of the changes fails.