pub fn elevate_install_node(cmd: &ElevateInstallNodeCommand) -> Result<()>Expand description
Installs a package with elevated privileges.
Errors
Returns an error if the node JSON file cannot be read, if the node JSON is invalid, or if the installation process fails.