pub fn write_manifest(manifest: &InstallManifest) -> Result<(), Error>
Writes an installation manifest to the store and updates the ‘latest’ symlink.
Returns an error if the manifest cannot be serialized or written.