Module mini_resolve

Module mini_resolve 

Minimal package resolution utilities.

Structs

MiniPackageIndex
A simplified version of package metadata used in Zoi Mini’s remote index.
MiniRegistryIndex
A mapping of package names to their metadata in the Mini index.
MiniVulnerability
A simplified vulnerability representation used in package indices.

Functions

check_vulnerabilities
Scans the package metadata for known security advisories.
fetch_registry_config
Fetches the repository configuration from the official Zoidberg registry.
fetch_registry_index
Fetches the optimized JSON index from the official Zoidberg registry.
get_package_lua_url
Returns the URL to download a package’s .pkg.lua file from the official registry.