MiniPackageIndex

Struct MiniPackageIndex 

pub struct MiniPackageIndex {
    pub repo: String,
    pub repo_type: String,
    pub version: String,
    pub revision: String,
    pub description: String,
    pub sub_packages: Option<Vec<String>>,
    pub vuln: Option<Vec<MiniVulnerability>>,
}
A simplified version of package metadata used in Zoi Mini’s remote index.

This index allows Zoi Mini to perform fast lookups and vulnerability checks without downloading individual .pkg.lua files or cloning entire registries.

Fields

repo: Stringrepo_type: Stringversion: Stringrevision: Stringdescription: Stringsub_packages: Option<Vec<String>>vuln: Option<Vec<MiniVulnerability>>