Module recorder

Module recorder 

Transaction recording and playback.

Functions

get_recorded_packages
Returns all recorded packages across all scopes.
record_package
Records a package installation or update in the lockfile.
remove_package_from_record
Removes a package from the lockfile record.
update_package_reason
Updates the installation reason for a package in the lockfile.