Package registry utilities.
Functions
- add_
advisory - Adds a new security advisory to the registry.
- add_
package - Adds a new package definition to the registry.
- check
- Checks the integrity of all package definitions in the registry.
- generate_
metadata - Scans the entire registry to generate optimized JSON index files.
- init
- Initializes a new Zoi registry at the given path.