pub fn check(registry_root: &Path) -> Result<(), Error>Expand description
Checks the integrity of all package definitions in the registry.
This runs zoi doctor on every .pkg.lua file in the registry.
Errors
Returns an error if any package fails the health check.