Module resolve

Module resolve 

Package resolution utilities.

Structs

PackageRequest
Represents a request for a package, parsed from a source string.
ResolvedSource
Represents a source that has been resolved to a local path.

Functions

get_db_root
Returns the root directory of the package database.
get_default_version
Returns the default version for a package.
parse_source_string
Parses a source string into a PackageRequest.
resolve_channel
Resolves a channel name to a concrete version.
resolve_package_and_version
Resolves a package and its version from a source string.
resolve_requested_version_spec
Resolves the requested version specification from a source string.
resolve_source
Resolves a source identifier into a concrete local path to a .pkg.lua file.
resolve_version_from_url
Resolves a version from a JSON URL for a given channel.