get_db_base_dir

Function get_db_base_dir 

pub fn get_db_base_dir(scope: Scope) -> Result<PathBuf, Error>
Returns the root directory of the package database for a given scope.

Errors

Returns an error if the home directory or current directory cannot be determined.