pub fn get_git_base_dir(scope: Scope) -> Result<PathBuf, Error>
Returns the root directory for Git repositories for a given scope.
Returns an error if the home directory or current directory cannot be determined.