pub fn remove_package_from_record(
manifest: &InstallManifest,
) -> Result<(), Error>Expand description
Removes a package from the lockfile record.
Errors
Returns an error if the lockfile cannot be read or written, or if the lockfile mutex is poisoned.